@@ -1,14 +1,45 @@
 import tempfile
 from pathlib import Path
+from typing import Union
 
 from tabml.examples.titanic import feature_manager, pipelines
 from tabml.experiment_manager import ExperimentManger
-from tabml.inference import ModelInference
+from tabml.inference import ModelInference, ModelInferenceCompact
 from tabml.utils.utils import change_working_dir_pytest
 
+RAW_DATA_SAMPLES = [
+    {
+        "PassengerId": 1,
+        "Pclass": 1,
+        "Name": "First, Mr. Last",
+        "Sex": "female",
+        "SibSp": 3,
+        "Parch": 0,
+        "Ticket": 12345,
+        "Fare": 10.0,
+        "Cabin": None,
+        "Embarked": "C",
+    },
+    {
+        "PassengerId": 2,
+        "Pclass": 1,
+        "Name": "First, Mrs. Last",
+        "Sex": "male",
+        "Age": 60,
+        "SibSp": 0,
+        "Parch": 2,
+        "Ticket": 12345,
+        "Fare": 100.0,
+        "Cabin": None,
+        "Embarked": "Q",
+    },
+]
+
 
 def _test_inference(
-    config_path, test_custom_pipeline_config_path=False, transformer_path=None
+    config_path,
+    test_custom_pipeline_config_path=False,
+    transformer_path: Union[Path, str] = "",
 ):
     feature_config_path = "./configs/feature_config.yaml"
     last_model_run_dir = ExperimentManger(config_path).get_most_recent_run_dir()
@@ -21,34 +52,19 @@ def _test_inference(
         model_path=model_path,
         pipeline_config_path=pipeline_config_path,
     )
-    raw_data_samples = [
-        {
-            "PassengerId": 1,
-            "Pclass": 1,
-            "Name": "First, Mr. Last",
-            "Sex": "female",
-            "SibSp": 3,
-            "Parch": 0,
-            "Ticket": 12345,
-            "Fare": 10.0,
-            "Cabin": None,
-            "Embarked": "C",
-        },
-        {
-            "PassengerId": 2,
-            "Pclass": 1,
-            "Name": "First, Mrs. Last",
-            "Sex": "male",
-            "Age": 60,
-            "SibSp": 0,
-            "Parch": 2,
-            "Ticket": 12345,
-            "Fare": 100.0,
-            "Cabin": None,
-            "Embarked": "Q",
-        },
-    ]
-    model_inference.predict(raw_data_samples)
+    model_inference.predict(RAW_DATA_SAMPLES)
+
+
+def _test_inference_compact(config_path):
+    full_pipeline_path = (
+        ExperimentManger(config_path).get_most_recent_run_dir()
+        / ExperimentManger.full_pipeline_filename
+    )
+    model_inference = ModelInferenceCompact(
+        feature_manager_cls=feature_manager.FeatureManager,  # type: ignore
+        full_pipeline_path=full_pipeline_path,
+    )
+    model_inference.predict(RAW_DATA_SAMPLES)
 
 
 @change_working_dir_pytest
@@ -60,12 +76,14 @@ def test_run():
 def test_full_pipeline_lgbm():
     pipelines.train_lgbm()
     _test_inference("./configs/lgbm_config.yaml")
+    _test_inference_compact("./configs/lgbm_config.yaml")
 
 
 @change_working_dir_pytest
 def test_full_pipeline_xgboost():
     pipelines.train_xgboost()
     _test_inference("./configs/xgboost_config.yaml")
+    _test_inference_compact("./configs/xgboost_config.yaml")
 
 
 @change_working_dir_pytest
@@ -74,6 +92,7 @@ def test_full_pipeline_catboost():
     _test_inference(
         "./configs/catboost_config.yaml", test_custom_pipeline_config_path=True
     )
+    _test_inference_compact("./configs/catboost_config.yaml")
 
 
 @change_working_dir_pytest
