@@ -23,6 +23,7 @@ class ExperimentManger:
     log_filename = "run.log"
     config_filename = "config.yaml"
     _model_analysis_dir = "model_analysis"
+    full_pipeline_filename = "full_pipeline.pickle"
 
     def __init__(
         self,
@@ -68,12 +69,15 @@ class ExperimentManger:
     def get_config_path(self):
         return self._make_path_under_run_dir(self.config_filename)
 
+    def get_full_pipeline_path(self):
+        return self._make_path_under_run_dir(self.full_pipeline_filename)
+
     def get_model_analysis_dir(self):
         res = self._make_path_under_run_dir(self._model_analysis_dir)
         _make_dir_if_needed(res)
         return res
 
-    def _make_path_under_run_dir(self, sub_path: str) -> str:
+    def _make_path_under_run_dir(self, sub_path: str) -> Path:
         return self.run_dir.joinpath(sub_path)
 
     def get_most_recent_run_dir(self):
@@ -107,7 +111,7 @@ class ExperimentManger:
         return str(run_dir / cls.config_filename)
 
 
-def _make_dir_if_needed(dir_path: str):
+def _make_dir_if_needed(dir_path: Union[str, Path]):
     if not Path(dir_path).exists():
         Path(dir_path).mkdir(parents=True)
 
