@@ -40,7 +40,9 @@ class TestFeatureConfigHelper:
         """
         config_path = tmp_path / "feature_config_str.yaml"
         write_str_to_file(feature_config_str, config_path)
-        cls.fm_helper = feature_config_helper.FeatureConfigHelper(config_path)
+        cls.fm_helper = feature_config_helper.FeatureConfigHelper.from_config_path(
+            config_path
+        )
 
     def test_raise_value_error_with_invalid_indexes(self, tmp_path):
         invalid_index_STRING = """
@@ -65,7 +67,7 @@ class TestFeatureConfigHelper:
         config_path = tmp_path / "tmp.yaml"
         write_str_to_file(invalid_index_STRING, config_path)
         with AssertRaises(ValueError) as assert_raises:
-            feature_config_helper.FeatureConfigHelper(config_path)
+            feature_config_helper.FeatureConfigHelper.from_config_path(config_path)
 
         error_message = assert_raises.expected_exception_found
         assert_eq(
@@ -95,8 +97,9 @@ class TestFeatureConfigHelper:
         """
         config_path = tmp_path / "tmp.yaml"
         write_str_to_file(config_STRING, config_path)
+        # feature_config = yaml.load(config_STRING)
         with AssertRaises(AssertionError) as assert_raises:
-            feature_config_helper.FeatureConfigHelper(config_path)
+            feature_config_helper.FeatureConfigHelper.from_config_path(config_path)
 
         error_message = assert_raises.expected_exception_found
         assert_eq(
@@ -123,7 +126,7 @@ class TestFeatureConfigHelper:
         config_path = tmp_path / "tmp.yaml"
         write_str_to_file(invalid_dependency_STRING, config_path)
         with AssertRaises(AssertionError) as assert_raises:
-            feature_config_helper.FeatureConfigHelper(config_path)
+            feature_config_helper.FeatureConfigHelper.from_config_path(config_path)
 
         error_message = assert_raises.expected_exception_found
         assert_eq(
